<?php
/**
*
* @package phpBB3 Football
* @version $Id: cron_remember_all 11 2011-03-13 08:03:21Z football $
* @copyright (c) 2010 football (http://football.bplaced.net)
* @license http://opensource.org/licenses/gpl-license.php GNU Public License
*
*/

// Stuff required to work with phpBB3
define ('IN_PHPBB', true);

$phpbb_root_path = (defined('PHPBB_ROOT_PATH')) ? PHPBB_ROOT_PATH : '../';

$phpEx = substr(strrchr(__FILE__, '.'), 1);
include($phpbb_root_path . 'common.' . $phpEx);
include($phpbb_root_path . 'football/includes/functions.' . $phpEx);

// Start session management
$user->session_begin();
$auth->acl($user->data);
if ($config['football_override_style'])
{
	$user->data['user_style'] = $config['football_style'];
	$user->setup('mods/lang_football', $config['football_style']);
}
else
{
	$user->setup('mods/lang_football');
}

//Check Access Code
$code = request_var('code', '');
if (strcmp($code, $config['football_code']) <> 0)
{
	exit;
}

//Football disabled?
if ($config['football_disable'])
{
	$message = (!empty($config['football_disable_msg'])) ? $config['football_disable_msg'] : 'FOOTBALL_DISABLED';
	trigger_error($message);
}

$season = curr_season();
$league = request_var('league', 0);


//Mail Settings
$use_queue = false;
$used_method = NOTIFY_EMAIL;
$priority = MAIL_NORMAL_PRIORITY;

if ($league)
{
	$where_league = " AND m.league = $league";
}
else
{
	$where_league = '';
}

//Matchdays to close in 24 hours and 9 hours later
$local_board_time = time() + (($config['board_timezone'] - $config['football_host_timezone']) * 3600); 
$sql = 'SELECT
		min(m.matchday) as matchday,
		min(m.delivery_date) as delivery_date,
		l.*
		FROM ' . FOOTB_MATCHDAYS . ' AS m
		LEFT JOIN ' . FOOTB_LEAGUES . " AS l ON (l.season = m.season AND l.league = m.league)
		WHERE m.season = $season AND m.status = 0 
			$where_league
		GROUP BY m.league";
$result = $db->sql_query($sql);
$toclose = $db->sql_fetchrowset($result);
$db->sql_freeresult($result);
foreach ($toclose as $close)
{

	$league 		= $close['league'];
	$league_name 	= $close['league_name'];
	$league_short 	= $close['league_name_short'];
	$delivery 		= $close['delivery_date'];
	$matchday 		= $close['matchday'];
	$subject 		= sprintf($user->lang['SUBJECT_REMEMBER'], $league_short, $matchday);
	$usernames 		= '';


	$sql = 'SELECT
			u.user_email AS user_email,
			u.username AS username,
			u.user_id AS userid,
			u.user_lang 
			FROM ' . FOOTB_BETS . ' AS b 
			LEFT JOIN ' . PROFILE_FIELDS_DATA_TABLE. ' AS p ON p.user_id = b.user_id
			LEFT JOIN ' . USERS_TABLE. " AS u ON u.user_id = b.user_id
			WHERE b.season = $season AND b.league = $league AND b.matchday = $matchday 
				AND p.pf_footb_rem_f = 1
			GROUP BY b.user_id
			UNION
			SELECT
			p.pf_footb_email  AS user_email,
			u.username AS username,
			u.user_id AS userid,
			u.user_lang
			FROM " . FOOTB_BETS . ' AS b 
			LEFT JOIN ' . PROFILE_FIELDS_DATA_TABLE. ' AS p ON p.user_id = b.user_id
			LEFT JOIN ' . USERS_TABLE. " AS u ON u.user_id = b.user_id
			WHERE b.season = $season AND b.league = $league AND b.matchday = $matchday 
				AND p.pf_footb_rem_s = 1
			GROUP BY b.user_id
			";
	$result = $db->sql_query($sql);
	$row = $db->sql_fetchrow($result);

	if (!$row)
	{
		$db->sql_freeresult($result);
	}
	else
	{

		// Send the messages
		include_once($phpbb_root_path . 'includes/functions_messenger.' . $phpEx);
		include_once($phpbb_root_path . 'includes/functions_user.' . $phpEx);
		$messenger = new messenger($use_queue);
		$errored = false;
		$messenger->headers('X-AntiAbuse: Board servername - ' . $config['server_name']);
		$messenger->headers('X-AntiAbuse: User_id - ' . $user->data['user_id']);
		$messenger->headers('X-AntiAbuse: Username - ' . $user->data['username']);
		$messenger->headers('X-AntiAbuse: User IP - ' . $user->ip);
		$messenger->subject(htmlspecialchars_decode($subject));
		$messenger->set_mail_priority($priority);

		do
		{
			$used_lang = $row['user_lang'];
			$messenger->to($row['user_email'], $row['username']);
			$messenger->template('footb_send_remember_all', $used_lang);

			$messenger->assign_vars(array(
				'USERNAME'		=> $row['username'],
				'LEAGUE'		=> $league_name,
				'MATCHDAY'		=> $matchday,
				'DELIVERY'		=> $delivery,
				'CONTACT_EMAIL' => $config['board_contact'])
			);

			if (!($messenger->send($used_method)))
			{
				$message = '<strong>' . sprintf($user->lang['SUBJECT_LOG_ERROR'], $league_short, $row['user_email']) . '</strong>';
				add_log('critical', 'LOG_ERROR_EMAIL', $message);
				$usernames .= (($usernames != '') ? ', ' : '') . $row['username']. '!';
			}
			else
			{
				$usernames .= (($usernames != '') ? ', ' : '') . $row['username'];
			}
		}
		while ($row = $db->sql_fetchrow($result));
		$db->sql_freeresult($result);

		if ($usernames)
		{
			$log_subject = sprintf($user->lang['SUBJECT_LOG'], $league_short, $usernames) ;
			add_log('admin', 'LOG_MASS_EMAIL', $log_subject);

			//send E-Mail to Board-Email
			$used_lang = $user->data['user_lang'];
			$subject = sprintf($user->lang['SUBJECT_BOARD'], $league_short, $matchday);
			$messenger->to($config['board_email'], $config['sitename']);
			$messenger->subject(htmlspecialchars_decode($subject));
			$messenger->template('footb_board_remember', $used_lang);
			$messenger->assign_vars(array(
				'CONTACT_EMAIL' => $config['board_contact'],
				'REMEMBER_LIST'	=> $usernames
				)
			);

			if (!($messenger->send($used_method)))
			{
				$message = '<strong>' . sprintf($user->lang['SUBJECT_BOARD_ERROR'], $league_short, $config['board_email']) . '</strong>';
				add_log('critical', 'LOG_ERROR_EMAIL', $message);
			}
		}
	}
}

?>
